@@ -1,29 +1,43 @@
-addBatch <- function (ds, ..., savepoint=TRUE, autorollback=savepoint, strict=TRUE, body=list(...)) {
+addBatch <- function (ds, ..., strict=TRUE, first_batch=FALSE, body=list(...)) {
     batches_url <- shojiURL(ds, "catalogs", "batches")
     if (!strict) {
         ## This is apparently deprecated in favor of passing in "strict" differently
         batches_url <- paste0(batches_url, "?strict=0")
     }
-    body <- wrapEntity(body=body)
-    body$autorollback <- autorollback
-    body$savepoint <- savepoint
 
-    if (autorollback) {
+    if (first_batch) {
+        ## If this is the first batch, it's an "import", so delete the dataset
+        ## if it fails--no need to keep a worthless dataset entity around
+        do_it <- function (expr) {
+            tryCatch(eval(expr), error=function (e) {
+                ## We failed to add the batch successfully, so we don't really have
+                ## a useful dataset. So delete the entity that was created initially
+                with_consent(delete(ds))
+                stop(e)
+            })
+        }
+    } else {
         ## Don't print "Result URL" if the job fails because the dataset will
         ## be rolled back and that URL won't exist
         do_it <- suppressMessages
-    } else {
-        ## Just execute and let the "Result URL" print if it fails
-        do_it <- force
     }
-    do_it(crPOST(batches_url, body=toJSON(body)))
+    do_it({
+        body <- wrapEntity(body=body)
+        suppressMessages(crPOST(batches_url, body=toJSON(body)))
+    })
     invisible(refresh(ds))
 }
 
 addBatchFile <- function (dataset, file, ...) {
     if (grepl("^[a-z0-9]+://", file)) {
         ## S3, or other file on the web
-        return(addBatch(dataset, url=file, ...))
+        if (startsWith(file, "s3")) {
+            ## We can post s3 URLs directly
+            return(addBatch(dataset, url=file, ...))
+        } else {
+            ## We have to create a source first
+            return(addBatch(dataset, source=createSource(url=file), ...))
+        }
     } else {
         ## Local file. Send it as file upload
         return(addBatch(dataset, source=createSource(file), ...))
@@ -31,9 +45,24 @@ addBatchFile <- function (dataset, file, ...) {
 }
 
 #' @importFrom httr upload_file
-createSource <- function (file, ...) {
-    crPOST(sessionURL("sources"),
-        body=list(uploaded_file=upload_file(file)), ...)
+createSource <- function (file, url, ...) {
+    sources_url <- sessionURL("sources")
+    if (!missing(file)) {
+        if (file.exists(file)) {
+            u <- crPOST(sources_url,
+                body=list(uploaded_file=upload_file(file)), ...)
+        } else {
+            halt("File not found")
+        }
+    } else if (!missing(url)) {
+        u <- crPOST(sources_url, body=toJSON(wrapEntity(location=url, ...)),
+            ## TODO: all JSON POSTs/PATCHes/PUTs should declare their content-type
+            ## this is just the first place where the backend has rejected without it
+            config=add_headers(`Content-Type`="application/json"))
+    } else {
+        halt("Must provide a file or url to createSource")
+    }
+    return(u)
 }
 
 #' @importFrom methods initialize
@@ -64,9 +93,9 @@ setMethod("names", "BatchCatalog", function (x) urls(x))
 #' "error" status batch records, which can cause confusion. This function lets
 #' you delete batches that don't match the status or statuses you want to keep.
 #' @param dataset CrunchDataset
-#' @param keep character batch status(es) you want to keep. By default, batches
+#' @param keep character the statuses that you want to keep. By default, batches
 #' that don't have either "imported" or "appended" status will be deleted.
-#' @return \code{dataset} with the undesired batches removed.
+#' @return `dataset` with the specified batches removed.
 #' @export
 cleanseBatches <- function (dataset, keep=c("imported", "appended")) {
     bat.cat <- batches(dataset)
