@@ -36,6 +36,19 @@ setMethod("ordering<-", "VariableCatalog", function (x, value) {
     stopifnot(inherits(value, "VariableOrder"))
 
     if (!identical(ordering(x)@graph, value@graph)) {
+        ## Give deprecation warning (the first time only per session)
+        if (!isTRUE(getOption("crunch.already.shown.folders.msg", FALSE))) {
+            warning(paste(
+                "Hey! There's a new way to organize variables within",
+                "datasets: the 'folder' methods. They're easier to use and",
+                "more reliable. See `?mv`, `?cd`, and others for details, and",
+                "`vignettes('variable-order', package='crunch')` for examples.",
+                "You're seeing this message because you're still using the",
+                "ordering<- method, which is fine today, but it will be going",
+                "away in the future, so check out the new methods."))
+            options(crunch.already.shown.folders.msg=TRUE)
+        }
+
         ## Validate.
         bad.entities <- setdiff(urls(value), urls(x))
         if (length(bad.entities)) {
@@ -73,9 +86,17 @@ setMethod("ordering<-", "DatasetCatalog", function (x, value) {
         ## Validate.
         bad.entities <- setdiff(urls(value), urls(x))
         if (length(bad.entities)) {
-            halt("Dataset URL", ifelse(length(bad.entities) > 1, "s", ""),
-                " referenced in Order not present in catalog: ",
-                serialPaste(bad.entities))
+            ## Due to some unidentified bug, we sometimes see order refs that
+            ## should have been removed but haven't been. So let's drop them
+            ## ourselves from the payload.
+            plural <- length(bad.entities) > 1
+            warning(
+                "Order contained dataset URL", ifelse(plural, "s", ""),
+                " not found in the catalog. ",
+                ifelse(plural, "They have", "It has"),
+                " been automatically cleaned."
+            )
+            value <- setdiff_entities(value, bad.entities, remove.na=TRUE)
         }
         ## Update on server
         crPUT(shojiURL(x, "orders", "order"), body=toJSON(value))
@@ -83,31 +104,6 @@ setMethod("ordering<-", "DatasetCatalog", function (x, value) {
     return(x)
 })
 
-
-# #' Move a variable to after another variable
-# #'
-# #' @param x the variable group that `after` is in
-# #' @param value the variable or dataset subset you would like to move
-# #' @param after the variable you want to precede `value`
-# #' @return returns a variable group
-# #' @examples
-# #' \dontrun{
-# #' ordering(ds)[['Demographics']] <- moveToAfter(ordering(ds)[['Grp A']], ds['age'], ds$educ)
-# #' }
-# moveToAfter <- function (x, value, after) {
-#     if (!inherits(after, "OrderGroup")) {
-#         after <- urls(after)
-#     }
-#     if (!inherits(value, "OrderGroup")) {
-#         value <- urls(value)
-#     }
-#     whi <- ifelse(inherits(after, "OrderGroup"), which(names(x) %in% name(after)), which(entities(x) %in% after))
-#     if ((inherits(value, "OrderGroup") && !name(value) %in% names(x)) || (!inherits(value, "OrderGroup") && !value %in% entities(x))) entities(x) <- c(entities(x), value)
-#     whi2 <- ifelse(inherits(value, "OrderGroup"), which(names(x) %in% name(value)), which(entities(x) %in% value))
-#     entities(x) <- entities(x)[c(setdiff(1:whi, whi2), whi2, setdiff((whi+1):length(entities(x)), whi2))]
-#     return(x)
-# }
-
 #' Copy the variable order from one dataset to another.
 #'
 #' @param source the dataset you want to copy the order from
