@@ -86,12 +86,26 @@ collateCats <- function (inserts, var_cats) {
     # setup an empty AbstractCategories object to collate into
     cats_out <- AbstractCategories()
     cats_out@.Data <- var_cats
+    
+    if (length(var_cats) < 1) {
+        halt("Can't collateCats with no categories.")
+    }
+    
+    last_category <- tail(ids(var_cats), 1)
 
     # for each insert, find the position for its anchor, and add the insertion
     # at that position we use a for loop, because as we insert, the positions of
-    # categories (which may serve as anchors) will change.
-    for (insert in inserts) {
-        pos <- findInsertPosition(insert, cats_out)
+    # categories (which may serve as anchors) will change. We also reverse the
+    # list because for insertions that have the same anchor, we want to maintain
+    # the order as it is stored in the API. To do this we insert the last one 
+    # first so that when we insert ones before that they are higher up (closer 
+    # to the category anchor)
+    # Categoies: A, B, C 
+    # Insertions: [{name = first, anchor = A}, {name = second, anchor = A}]
+    # Desired result: A, first, second, B, C
+    # Result if not `rev(inserts)`: A, second, first, B, C
+    for (insert in rev(inserts)) {
+        pos <- findInsertPosition(insert, cats_out, last_category)
         cats_out@.Data <- append(cats_out, list(insert), pos)
     }
     return(cats_out)
@@ -99,10 +113,10 @@ collateCats <- function (inserts, var_cats) {
 
 # for a single Insertion, and a set of categories (or collated categories and
 # insertions) find the position to insert to
-findInsertPosition <- function (insert, cats) {
+findInsertPosition <- function (insert, cats, last_category) {
     anchr <- anchor(insert)
-    # if the anchor is 0, put at the beginning
-    if (anchr == 0 | anchr == "top") {
+    # if the anchor is top, put at the beginning
+    if (anchr == "top") {
         return(0)
     }
 
@@ -114,8 +128,8 @@ findInsertPosition <- function (insert, cats) {
         }
     }
 
-    # all other situations, put at the end
-    return(Inf)
+    # all other situations, put after the last category
+    return(which(last_category == ids(cats)))
 }
 
 #' Given a vector of values and elements, calculate the insertions
