@@ -31,18 +31,17 @@ with_test_authentication({
         kube <- crtabs(~ v4 + MR, data=mrds, useNA="ifany")
         expect_is(kube, "CrunchCube")
         expect_equivalent(as.array(kube),
-            array(c(2, 0, 1, 0, 1, 0, 0, 1), dim=c(2L, 4L),
-                dimnames=list(v4=c("B", "C"),
-                MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                          array(c(2, 0, 1, 0, 1, 0), dim=c(2L, 3L),
+                                dimnames=list(v4=c("B", "C"),
+                                              MR=c("mr_1", "mr_2", "mr_3"))))
 
         kube@useNA <- "always"
         expect_equivalent(as.array(kube),
-            array(c(2, 0, 0,
-                    1, 0, 0,
-                    1, 0, 0,
-                    0, 1, 0), dim=c(3L, 4L),
-                dimnames=list(v4=c("B", "C", "No Data"),
-                MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                          array(c(2, 0, 0,
+                                  1, 0, 0,
+                                  1, 0, 0), dim=c(3L, 3L),
+                                dimnames=list(v4=c("B", "C", "No Data"),
+                                              MR=c("mr_1", "mr_2", "mr_3"))))
     })
 
     c1 <- crtabs(~ MR, data=mrds)
@@ -55,8 +54,8 @@ with_test_authentication({
         c2 <- c1
         c2@useNA <- "always"
         expect_equivalent(prop.table(c2),
-            array(c(.5, .25, .25, .25), dim=c(4L),
-                dimnames=list(MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+            array(c(.5, .25, .25), dim=c(3L),
+                dimnames=list(MR=c("mr_1", "mr_2", "mr_3"))))
     })
 
     c1 <- crtabs(~ v5 + MR, data=mrds)
@@ -69,13 +68,17 @@ with_test_authentication({
             array(c(1, 1, 0, 1, 0, 1), dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
                 MR=c("mr_1", "mr_2", "mr_3"))))
-        expect_equivalent(margin.table(c1), 3)
+        expect_equivalent(margin.table(c1),
+                          array(c(3, 3, 3), dim=c(3L),
+                                dimnames=list(MR=c("mr_1", "mr_2", "mr_3"))))
         expect_equivalent(prop.table(c1),
             array(c(1, 1, 0, 1, 0, 1)/3, dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
                 MR=c("mr_1", "mr_2", "mr_3"))))
         expect_equivalent(margin.table(c1, 1),
-            as.array(c(2, 1)))
+            array(c(2, 1, 2, 1, 2, 1), dim=c(2L, 3L),
+                     dimnames=list(v5=c("A", "B"),
+                                   MR=c("mr_1", "mr_2", "mr_3"))))
         expect_equivalent(prop.table(c1, margin=1),
             array(c(.5, 1, 0, 1, 0, 1), dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
@@ -95,32 +98,37 @@ with_test_authentication({
     #   B    1    1    1    1
     test_that("prop.table on bivariate with MR, margin=NULL, useNA=ifany", {
         expect_equivalent(as.array(c2),
-            array(c(1, 1, 0, 1, 0, 1, 0, 1), dim=c(2L, 4L),
+            array(c(1, 1, 0, 1, 0, 1), dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
-                MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                MR=c("mr_1", "mr_2", "mr_3"))))
 
         ## Sweep the whole table
-        expect_equivalent(margin.table(c2), 4)
+        expect_equivalent(margin.table(c2),
+                          array(c(4, 4, 4), dim=c(3L),
+                                dimnames=list(MR=c("mr_1", "mr_2", "mr_3"))))
         expect_equivalent(prop.table(c2),
-            array(c(1, 1, 0, 1, 0, 1, 0, 1)/4, dim=c(2L, 4L),
+            array(c(1, 1, 0, 1, 0, 1)/4, dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
-                MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                MR=c("mr_1", "mr_2", "mr_3"))))
     })
     test_that("prop.table on bivariate with MR, margin=1, useNA=ifany", {
         expect_equivalent(margin.table(c2, 1),
-            as.array(c(2, 2)))
+            array(c(2, 2, 2, 2, 2, 2), dim=c(2, 3L),
+                  dimnames=list(v5=c("A", "B"),
+                                MR=c("mr_1", "mr_2", "mr_3"))))
         expect_equivalent(prop.table(c2, margin=1),
-            array(c(.5, .5, 0, .5, 0, .5, 0, .5), dim=c(2L, 4L),
+            array(c(.5, .5, 0, .5, 0, .5), dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
-                MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                MR=c("mr_1", "mr_2", "mr_3"))))
     })
     test_that("prop.table on bivariate with MR, margin=2, useNA=ifany", {
         expect_equivalent(margin.table(c2, 2),
-            as.array(c(2, 1, 1, 1)))
+            array(c(2, 1, 1), dim=c(3L),
+                  dimnames=list(MR=c("mr_1", "mr_2", "mr_3"))))
         expect_equivalent(prop.table(c2, margin=2),
-            array(c(.5, .5, 0, 1, 0, 1, 0, 1), dim=c(2L, 4L),
+            array(c(.5, .5, 0, 1, 0, 1), dim=c(2L, 3L),
                 dimnames=list(v5=c("A", "B"),
-                MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                MR=c("mr_1", "mr_2", "mr_3"))))
     })
 
     cube.as.CA <- array(c(1, 2, 2, 2, 1, 1, 1, 1, 1),
