@@ -97,10 +97,12 @@ with_mock_crunch({
 })
 
 adims <- CubeDims(list(
-    v4=list(name=c("B", "C"), any.or.none=rep(FALSE, 2),
-        missing=rep(FALSE, 2), references=list(name="v4")),
-    v7=list(name=c("C", "D", "E", "No Data"), any.or.none=rep(FALSE, 4),
-        missing=c(rep(FALSE, 3), TRUE), references=list(name="v7"))))
+    v4=list(name=c("B", "C"),
+        missing=rep(FALSE, 2),
+        references=list(name="v4", alias="v4", type="categorical")),
+    v7=list(name=c("C", "D", "E", "No Data"),
+        missing=c(rep(FALSE, 3), TRUE),
+        references=list(name="v7", alias="v7", type="categorical"))))
 a1 <- CrunchCube(arrays=list("count"=array(c(
         8, 6,
         3, 2,
@@ -135,16 +137,6 @@ test_that("simple margin.table", {
     expect_identical(margin.table(a1), 24)
 })
 
-test_that("margin.table with any/none", {
-    a2 <- a1
-    a2@dims[[2]]$any.or.none[1] <- TRUE ## "C"
-    expect_identical(margin.table(a2, 1),
-        cubify(8, 6, dims=df.dims["v4"]))
-    expect_identical(margin.table(a2, 2),
-        cubify(5, 5, dims=list(v7=LETTERS[4:5])))
-    expect_identical(margin.table(a2), 14)
-})
-
 test_that("margin.table with missing", {
     a2 <- a1
     a2@dims[[2]]$missing[2] <- TRUE ## "D"
