@@ -97,14 +97,6 @@ with_mock_crunch({
         )
     })
 
-    test_that("is.TRUEorFALSE errors correctly", {
-        expect_true(is.TRUEorFALSE(TRUE))
-        expect_true(is.TRUEorFALSE(FALSE))
-        expect_false(is.TRUEorFALSE("char"))
-        expect_false(is.TRUEorFALSE(NA))
-        expect_false(is.TRUEorFALSE(c(TRUE, TRUE)))
-    })
-
     test_that("generateWeightEntry errors correctly", {
         expect_error(generateWeightEntry("bad_formula"),
             paste0(dQuote("bad_formula"),
